import events = require('@aws-cdk/aws-events');
import s3 = require('@aws-cdk/aws-s3');
import cdk = require('@aws-cdk/cdk');
import { Artifact } from './artifact';
import { cloudformation } from './codepipeline.generated';
import { Stage } from './stage';
export declare enum ActionCategory {
    Source = "Source",
    Build = "Build",
    Test = "Test",
    Approval = "Approval",
    Deploy = "Deploy",
    Invoke = "Invoke"
}
/**
 * Specifies the constraints on the number of input and output
 * artifacts an action can have.
 *
 * The constraints for each action type are documented on the
 * {@link https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html Pipeline Structure Reference} page.
 */
export interface ActionArtifactBounds {
    minInputs: number;
    maxInputs: number;
    minOutputs: number;
    maxOutputs: number;
}
export declare function defaultBounds(): ActionArtifactBounds;
/**
 * Construction properties of the low level {@link Action action type}.
 */
export interface ActionProps {
    /**
     * A category that defines which action type the owner (the entity that performs the action) performs.
     * The category that you select determine the providers that you can specify for the {@link #provider} property.
     */
    category: ActionCategory;
    /**
     * The service provider that the action calls. The providers that you can specify are determined by
     * the category that you select. For example, a valid provider for the Deploy category is AWS CodeDeploy,
     * which you would specify as CodeDeploy.
     */
    provider: string;
    /**
     * The constraints to apply to the number of input and output artifacts used by this action.
     */
    artifactBounds: ActionArtifactBounds;
    /**
     * The action's configuration. These are key-value pairs that specify input values for an action.
     * For more information, see the AWS CodePipeline User Guide.
     *
     * http://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html#action-requirements
     */
    configuration?: any;
    /**
     * For all currently supported action types, the only valid version string is "1".
     *
     * @default 1
     */
    version?: string;
    /**
     * For all currently supported action types, the only valid owner string is
     * "AWS", "ThirdParty", or "Custom". For more information, see the AWS
     * CodePipeline API Reference.
     *
     * @default 'AWS'
     */
    owner?: string;
}
/**
 * Low level class for generically creating pipeline actions.
 * It is recommended that concrete types are used instead, such as {@link codecommit.PipelineSource} or
 * {@link codebuild.PipelineBuildAction}.
 */
export declare abstract class Action extends cdk.Construct {
    /**
     * The category of the action. The category defines which action type the owner (the entity that performs the action) performs.
     */
    readonly category: ActionCategory;
    /**
     * The service provider that the action calls.
     */
    readonly provider: string;
    /**
     * The action's configuration. These are key-value pairs that specify input values for an action.
     * For more information, see the AWS CodePipeline User Guide.
     *
     * http://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html#action-requirements
     */
    readonly configuration?: any;
    /**
     * The order in which AWS CodePipeline runs this action.
     * For more information, see the AWS CodePipeline User Guide.
     *
     * https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html#action-requirements
     */
    runOrder: number;
    private readonly artifactBounds;
    private readonly inputArtifacts;
    private readonly outputArtifacts;
    private readonly owner;
    private readonly version;
    private readonly stage;
    constructor(parent: Stage, name: string, props: ActionProps);
    validate(): string[];
    /**
     * Render the Action to a CloudFormation struct
     */
    render(): cloudformation.PipelineResource.ActionDeclarationProperty;
    onStateChange(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * If an Artifact is added as a child, add it to the list of output artifacts.
     */
    protected addChild(child: cdk.Construct, name: string): void;
    protected addOutputArtifact(name: string): Artifact;
    protected addInputArtifact(artifact: Artifact): Action;
}
/**
 * Construction properties of the low level {@link Source source action}
 */
export interface SourceProps {
    /**
     * The source action owner (could e "AWS", "ThirdParty" or "Custom")
     *
     * @default AWS
     */
    owner?: string;
    /**
     * The source action verison.
     *
     * @default "1"
     */
    version?: string;
    /**
     * The name of the source's output artifact. Output artifacts are used by CodePipeline as
     * inputs into other actions.
     */
    artifactName: string;
    /**
     * The service provider that the action calls. For example, a valid provider for Source actions is S3.
     */
    provider: string;
    /**
     * The action's configuration. These are key-value pairs that specify input values for an action.
     * For more information, see the AWS CodePipeline User Guide.
     *
     * http://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html#action-requirements
     */
    configuration?: any;
}
/**
 * Low level class for source actions.
 * It is recommended that concrete types are used instead, such as {@link AmazonS3Source} or
 * {@link codecommit.PipelineSource}.
 */
export declare abstract class Source extends Action {
    readonly artifact: Artifact;
    constructor(parent: Stage, name: string, props: SourceProps);
}
/**
 * Construction properties of the {@link AmazonS3Source S3 source action}
 */
export interface AmazonS3SourceProps {
    /**
     * The name of the source's output artifact. Output artifacts are used by CodePipeline as
     * inputs into other actions.
     */
    artifactName: string;
    /**
     * The Amazon S3 bucket that stores the source code
     */
    bucket: s3.BucketRef;
    /**
     * The key within the S3 bucket that stores the source code
     */
    bucketKey: string;
    /**
     * Whether or not AWS CodePipeline should poll for source changes
     *
     * @default true
     */
    pollForSourceChanges?: boolean;
}
/**
 * Source that is provided by a specific Amazon S3 object
 */
export declare class AmazonS3Source extends Source {
    constructor(parent: Stage, name: string, props: AmazonS3SourceProps);
}
/**
 * Construction properties of the {@link GitHubSource GitHub source action}
 */
export interface GithubSourceProps {
    /**
     * The name of the source's output artifact. Output artifacts are used by CodePipeline as
     * inputs into other actions.
     */
    artifactName: string;
    /**
     * The GitHub account/user that owns the repo.
     */
    owner: string;
    /**
     * The name of the repo, without the username.
     */
    repo: string;
    /**
     * The branch to use.
     *
     * @default "master"
     */
    branch?: string;
    /**
     * A GitHub OAuth token to use for authentication.
     *
     * It is recommended to use a `SecretParameter` to obtain the token from the SSM
     * Parameter Store:
     *
     *     const oauth = new SecretParameter(this, 'GitHubOAuthToken', { ssmParameter: 'my-github-token });
     *     new GitHubSource(stage, 'GH' { oauthToken: oauth });
     *
     */
    oauthToken: cdk.Secret;
    /**
     * Whether or not AWS CodePipeline should poll for source changes
     *
     * @default true
     */
    pollForSourceChanges?: boolean;
}
/**
 * Source that is provided by a GitHub repository
 */
export declare class GitHubSource extends Source {
    constructor(parent: Stage, name: string, props: GithubSourceProps);
}
/**
 * Construction properties of the low level {@link BuildAction build action}
 */
export interface BuildActionProps {
    /**
     * The source to use as input for this build
     */
    inputArtifact: Artifact;
    /**
     * The service provider that the action calls. For example, a valid provider for Source actions is CodeBuild.
     */
    provider: string;
    /**
     * The name of the build's output artifact
     */
    artifactName?: string;
    /**
     * The action's configuration. These are key-value pairs that specify input values for an action.
     * For more information, see the AWS CodePipeline User Guide.
     *
     * http://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html#action-requirements
     */
    configuration?: any;
}
/**
 * Low level class for build actions.
 * It is recommended that concrete types are used instead, such as {@link codebuild.PipelineBuildAction}.
 */
export declare abstract class BuildAction extends Action {
    readonly artifact?: Artifact;
    constructor(parent: Stage, name: string, props: BuildActionProps);
}
/**
 * Manual approval action
 */
export declare class ApprovalAction extends Action {
    constructor(parent: Stage, name: string);
}
export declare class DeployAction extends Action {
    constructor(parent: Stage, name: string, provider: string, artifactBounds: ActionArtifactBounds, configuration?: any);
}
